..
    :copyright: Copyright (c) 2014 ftrack

.. _developing/locations:

*********
Locations
*********

Learn how to access locations using the API and configure your own location
plugins.

.. toctree::
    :maxdepth: 1

    overview
    tutorial
    configuring
